@@ -190,6 +190,18 @@ class NonResponsiveGuestAgent(VdsmException):
 
 
 # codes 20-35 are reserved for add/delNetwork
+
+
+class UnsupportedDriveType(ContextException):
+    code = 36
+    message = 'Unsupported drive type'
+
+
+class LUNDoesNotExist(ContextException):
+    code = 37
+    message = 'LUN does not exist'
+
+
 # code 39 was used for:
 # wrongHost - migration destination has an invalid hostname
 
@@ -545,3 +557,14 @@ class MergeBitmapError(ContextException):
 class RemoveBitmapError(ContextException):
     code = 1622
     message = "Failed to remove bitmap"
+
+
+#################################################
+#  Image Errors
+#  Range: 1630-1639
+#################################################
+
+
+class CannotPrepareImage(ContextException):
+    code = 1630
+    msg = "Failed to prepare image"
