@@ -33,7 +33,10 @@ import shutil
 import stat
 import subprocess
 import sys
+import tempfile
+import time
 
+import selinux
 import six
 
 from vdsm import constants
@@ -251,6 +254,47 @@ def chown(path, user=-1, group=-1):
     return True
 
 
+def backup_file(filename):
+    """
+    Backup filename with a timestamp and returns the backup filename.
+    """
+    if os.path.exists(filename):
+        backup = filename + '.' + time.strftime("%Y%m%d%H%M%S")
+        shutil.copyfile(filename, backup)
+        return backup
+
+
+def atomic_write(filename, data, mode=0o644, relabel=False):
+    """
+    Write data to filename atomically using a temporary file.
+
+    Arguments:
+        filename (str): Path to file.
+        data (bytes): Data to write to filename.
+        mode (int): Set mode bits on filename.
+        relabel (bool): If True, set selinux label.
+    """
+    with tempfile.NamedTemporaryFile(
+            mode="wb",
+            dir=os.path.dirname(filename),
+            prefix=os.path.basename(filename) + ".tmp",
+            delete=False) as tmp:
+        try:
+            tmp.write(data)
+            tmp.flush()
+
+            if relabel:
+                # Force required to preserve "system_u". Without it the
+                # temporary file will be labeled as "unconfined_u".
+                selinux.restorecon(tmp.name, force=True)
+
+            os.chmod(tmp.name, mode)
+            os.rename(tmp.name, filename)
+        except:
+            os.unlink(tmp.name)
+            raise
+
+
 def atomic_symlink(target, name):
     """
     Create s symbolic link atomically, updating stale links.
