@@ -25,12 +25,12 @@ import uuid
 import xml.etree.ElementTree as ET
 
 from vdsm.common import concurrent
-from vdsm.common import errors
 from vdsm.common import logutils
 from vdsm.common import response
 from vdsm.common.define import doneCode, errCode
+
+from vdsm.virt import errors
 from vdsm.virt import virdomain
-from vdsm.virt import vm
 from vdsm.virt.vmdevices.storage import DISK_TYPE, VolumeNotFound
 
 import libvirt
@@ -113,7 +113,7 @@ class DriveMerger:
                                               drive.imageID, baseVolUUID)
             topInfo = self._vm.getVolumeInfo(drive.domainID, drive.poolID,
                                              drive.imageID, topVolUUID)
-        except vm.StorageUnavailableError:
+        except errors.StorageUnavailableError:
             log.error("Unable to get volume information")
             return errCode['mergeErr']
 
@@ -242,10 +242,15 @@ class DriveMerger:
         try:
             job = self._get_block_job(drive)
         except LookupError:
-            newJob = {'jobID': jobID, 'disk': driveSpec,
-                      'baseVolume': base, 'topVolume': top,
-                      'strategy': strategy, 'blockJobType': 'commit',
-                      'drive': drive.name}
+            newJob = {
+                'baseVolume': base,
+                'blockJobType': 'commit',
+                'disk': driveSpec,
+                'drive': drive.name,
+                'jobID': jobID,
+                'strategy': strategy,
+                'topVolume': top,
+            }
             self._blockJobs[jobID] = newJob
         else:
             log.error("Cannot add block job %s.  A block job with id "
@@ -289,12 +294,12 @@ class DriveMerger:
             return len(self._blockJobs) > 0
 
     def queryBlockJobs(self):
-        def startCleanup(job, drive, needPivot):
-            t = LiveMergeCleanupThread(self._vm, job, drive, needPivot)
-            t.start()
-            self._liveMergeCleanupThreads[job['jobID']] = t
+        """
+        Query tracked jobs and update their status. Returns dict of tracked
+        jobs dict, for reporting job status to engine.
+        """
+        tracked_jobs = {}
 
-        jobsRet = {}
         # We need to take the jobs lock here to ensure that we don't race with
         # another call to merge() where the job has been recorded but not yet
         # started.
@@ -302,12 +307,13 @@ class DriveMerger:
             for storedJob in list(self._blockJobs.values()):
                 jobID = storedJob['jobID']
                 log.debug("Checking job %s", jobID)
+
+                # Handle successful jobs early because the job just needs
+                # to be untracked and the stored disk info might be stale
+                # anyway (ie. after active layer commit).
                 cleanThread = self._liveMergeCleanupThreads.get(jobID)
                 if (cleanThread
                         and cleanThread.state == LiveMergeCleanupThread.DONE):
-                    # Handle successful jobs early because the job just needs
-                    # to be untracked and the stored disk info might be stale
-                    # anyway (ie. after active layer commit).
                     log.info("Cleanup thread %s successfully completed, "
                              "untracking job %s (base=%s, top=%s)",
                              cleanThread, jobID,
@@ -325,7 +331,9 @@ class DriveMerger:
                     if disk["volumeID"] != storedJob["topVolume"]:
                         log.error("Cannot find drive for job %s (disk=%s)",
                                   jobID, storedJob['disk'])
+                        # TODO: Should we report this job?
                         continue
+
                     # Active layer merge, check if pivot completed.
                     pivoted_drive = dict(disk)
                     pivoted_drive["volumeID"] = storedJob["baseVolume"]
@@ -335,12 +343,20 @@ class DriveMerger:
                         log.error("Pivot completed but cannot find drive "
                                   "for job %s (disk=%s)",
                                   jobID, pivoted_drive)
+                        # TODO: Should we report this job?
                         continue
-                entry = {'id': jobID, 'jobType': 'block',
-                         'blockJobType': storedJob['blockJobType'],
-                         'bandwidth': 0, 'cur': '0', 'end': '0',
-                         'imgUUID': storedJob['disk']['imageID'],
-                         'drive': storedJob['drive']}
+
+                # Tracked job info for reporting to engine.
+                job_info = {
+                    'bandwidth': 0,
+                    'blockJobType': storedJob['blockJobType'],
+                    'cur': '0',
+                    'drive': storedJob['drive'],
+                    'end': '0',
+                    'id': jobID,
+                    'imgUUID': storedJob['disk']['imageID'],
+                    'jobType': 'block',
+                }
 
                 liveInfo = None
                 if 'gone' not in storedJob:
@@ -349,14 +365,14 @@ class DriveMerger:
                         liveInfo = self._dom.blockJobInfo(drive.name, 0)
                     except libvirt.libvirtError:
                         log.exception("Error getting block job info")
-                        jobsRet[jobID] = entry
+                        tracked_jobs[jobID] = job_info
                         continue
 
                 if liveInfo:
                     log.debug("Job %s live info: %s", jobID, liveInfo)
-                    entry['bandwidth'] = liveInfo['bandwidth']
-                    entry['cur'] = str(liveInfo['cur'])
-                    entry['end'] = str(liveInfo['end'])
+                    job_info['bandwidth'] = liveInfo['bandwidth']
+                    job_info['cur'] = str(liveInfo['cur'])
+                    job_info['end'] = str(liveInfo['end'])
                     doPivot = self._activeLayerCommitReady(liveInfo, drive)
                 else:
                     # Libvirt has stopped reporting this job so we know it will
@@ -365,13 +381,14 @@ class DriveMerger:
                         log.info("Libvirt job %s was terminated", jobID)
                     storedJob['gone'] = True
                     doPivot = False
+
                 if not liveInfo or doPivot:
                     if not cleanThread:
                         # There is no cleanup thread so the job must have just
                         # ended.  Spawn an async cleanup.
                         log.info("Starting cleanup thread for job: %s",
                                  jobID)
-                        startCleanup(storedJob, drive, doPivot)
+                        self._start_cleanup_thread(storedJob, drive, doPivot)
                     elif cleanThread.state == LiveMergeCleanupThread.TRYING:
                         # Let previously started cleanup thread continue
                         log.debug("Still waiting for block job %s to be "
@@ -380,15 +397,24 @@ class DriveMerger:
                         log.info("Previous job %s cleanup thread failed with "
                                  "recoverable error, retrying",
                                  jobID)
-                        startCleanup(storedJob, drive, doPivot)
+                        self._start_cleanup_thread(storedJob, drive, doPivot)
                     elif cleanThread.state == LiveMergeCleanupThread.ABORT:
                         log.error("Aborting job %s due to an unrecoverable "
                                   "error", jobID)
                         self._untrack_block_job(jobID)
-                        # Don't report job as progressing in returned jobs.
                         continue
-                jobsRet[jobID] = entry
-        return jobsRet
+
+                tracked_jobs[jobID] = job_info
+
+        return tracked_jobs
+
+    def _start_cleanup_thread(self, job, drive, needPivot):
+        """
+        Must be caller when holding self._jobsLock.
+        """
+        t = LiveMergeCleanupThread(self._vm, job, drive, needPivot)
+        t.start()
+        self._liveMergeCleanupThreads[job['jobID']] = t
 
     def _activeLayerCommitReady(self, jobInfo, drive):
         try:
@@ -515,7 +541,7 @@ class LiveMergeCleanupThread(object):
             self.drive.imageID,
             self.job['topVolume'])
         if ret['status']['code'] != 0:
-            raise vm.StorageUnavailableError(
+            raise errors.StorageUnavailableError(
                 "Failed to teardown top volume %s" %
                 self.job['topVolume'])
 
