@@ -43,6 +43,7 @@ from vdsm.virt import recovery
 from vdsm.virt import sampling
 from vdsm.virt import virdomain
 from vdsm.virt import vmstatus
+from vdsm.virt.externaldata import ExternalDataKind
 
 
 # Just a made up number. Maybe should be equal to number of cores?
@@ -383,7 +384,8 @@ class DriveWatermarkMonitor(_RunnableOnVm):
         self._vm.monitor_drives()
 
 
-class TpmDataMonitor(_RunnableOnVm):
+class _ExternalDataMonitor(_RunnableOnVm):
+    KIND = None
 
     @property
     def required(self):
@@ -399,13 +401,22 @@ class TpmDataMonitor(_RunnableOnVm):
 
     def _execute(self):
         try:
-            self._vm.update_tpm()
+            self._vm.update_external_data(self.KIND)
         except Exception as e:
             if self._vm.lastStatus == vmstatus.UP:
                 log = self._vm.log.error
             else:
                 log = self._vm.log.info
-            log("Periodic TPM data retrieval failed: %s", e)
+            log("Periodic external data retrieval failed (%s): %s",
+                self.KIND, e)
+
+
+class TpmDataMonitor(_ExternalDataMonitor):
+    KIND = ExternalDataKind.TPM
+
+
+class NvramDataMonitor(_ExternalDataMonitor):
+    KIND = ExternalDataKind.NVRAM
 
 
 def _kill_long_paused_vms(cif):
@@ -442,6 +453,10 @@ def _create(cif, scheduler):
             DriveWatermarkMonitor,
             config.getint('vars', 'vm_watermark_interval')),
 
+        per_vm_operation(
+            NvramDataMonitor,
+            config.getint('sampling', 'nvram_data_update_interval')),
+
         per_vm_operation(
             TpmDataMonitor,
             config.getint('sampling', 'tpm_data_update_interval')),
